program IMGTest;
{*****************************************************************************
** Image unit testing program,                                             **
**   by Steven Don                                                         **
*****************************************************************************
** This program is a test for the image unit. It loads an image in each    **
** of the 3 supported formats.                                             **
**                                                                         **
** For questions, feel free to e-mail me.                                  **
**                                                                         **
**    shd@earthling.net                                                    **
**    http://shd.cjb.net                                                   **
**                                                                         **
****************************************************************************}

{Any program using the image unit, must have a stack of at least 19.5K}
{$M 19500, 0, 655360}
uses IMGUnit, Crt;

{This sets the display to VGA 320x200 in 256 colours}
procedure VGAScreen; assembler;
asm
  mov ax, 13h
  int 10h
end;

{This resets the display to text mode}
procedure TextScreen; assembler;
asm
  mov ax, 3h
  int 10h
end;

var
  ScreenPTR : Pointer;

begin
  {Switch to VGA mode}
  VGAScreen;

  {Set up a pointer to the VGA screen}
  ScreenPTR := Ptr ($A000, 0000);

  {Try loading TEST.BMP, directly to the screen}
  if LoadBMP ('TEST.BMP', ScreenPTR) then begin
    ReadKey;
  end else begin
    {If it failed, switch back to text}
    TextScreen;
    {Display an error message}
    Write ('Error loading TEST.BMP: ');
    case IMGError of
      FileNotFound      : Writeln ('File not found.');
      UnsupportedFormat : Writeln ('Unsupported BMP format.');
      TooLarge          : Writeln ('Larger than screen.');
    end;
    {Wait for a keypress}
    Writeln ('Press any key to continue...');
    ReadKey;
    {And switch back to graphics mode}
    VGAScreen;
  end;

  {The same for TEST.PCX}
  if LoadPCX ('TEST.PCX', ScreenPTR) then begin
    ReadKey;
  end else begin
    TextScreen;
    Write ('Error loading TEST.PCX: ');
    case IMGError of
      FileNotFound      : Writeln ('File not found.');
      UnsupportedFormat : Writeln ('Unsupported PCX format.');
      TooLarge          : Writeln ('Larger than screen.');
    end;
    Writeln ('Press any key to continue...');
    ReadKey;
    VGAScreen;
  end;

  {And TEST.GIF}
  if LoadGIF ('TEST.GIF', ScreenPTR) then begin
    ReadKey;
  end else begin
    TextScreen;
    Write ('Error loading TEST.GIF: ');
    case IMGError of
      FileNotFound      : Writeln ('File not found.');
      UnsupportedFormat : Writeln ('Unsupported GIF format.');
      TooLarge          : Writeln ('Larger than screen.');
    end;
    Writeln ('Press any key to continue...');
    ReadKey;
    VGAScreen;
  end;

  TextScreen;
end.